pub struct FileRefContext(/* private fields */);Expand description
Table context needed to locate a FILE column value for downloads.
Implementations
Sourceimpl FileRefContext
impl FileRefContext
Sourcepub fn new(table_id: TableId) -> FileRefContext
pub fn new(table_id: TableId) -> FileRefContext
Create a new file reference context from a TableId.
Sourcepub fn from_strings(namespace: &str, table: &str) -> FileRefContext
pub fn from_strings(namespace: &str, table: &str) -> FileRefContext
Create a file reference context from namespace and table name strings.