SubscriptionOptions

Struct SubscriptionOptions 

pub struct SubscriptionOptions {
    pub batch_size: Option<usize>,
    pub last_rows: Option<u32>,
    pub from: Option<SeqId>,
    pub auto_fetch_batches: Option<bool>,
}
Options for live query subscriptions.

Fields

batch_size: Option<usize>

Hint for server-side batch sizing during initial data load.

last_rows: Option<u32>

Number of last (newest) rows to fetch for initial data.

from: Option<SeqId>

Resume subscription from a specific sequence ID.

auto_fetch_batches: Option<bool>

Client-side control for automatically requesting subsequent initial data batches.

Implementations

Source

impl SubscriptionOptions

pub fn new() -> SubscriptionOptions

Create new subscription options with defaults.

pub fn with_batch_size(self, size: usize) -> SubscriptionOptions

Set the batch size for initial data loading.

pub fn with_last_rows(self, count: u32) -> SubscriptionOptions

Set the number of last rows to fetch.

pub fn with_from(self, seq_id: SeqId) -> SubscriptionOptions

Resume from a specific sequence ID.

pub fn with_from_seq_id(self, seq_id: SeqId) -> SubscriptionOptions

Resume from a specific sequence ID via deprecated alias.

pub fn with_auto_fetch_batches(self, enabled: bool) -> SubscriptionOptions

Control whether the client should automatically request subsequent initial data batches.

pub fn has_resume_seq_id(&self) -> bool

Check if this contains a resume seq_id.