pub struct TableId { /* private fields */ }Expand description
Composite key for system.tables entries: (namespace_id, table_name)
This composite key provides type-safe access to table metadata, ensuring namespace and table name are always paired correctly.
Serialization
Serializes as “namespace.table” string format for JSON compatibility.
For example: "flush_test_ns_mkav1q2g_3.metrics"
Implementations
Sourceimpl TableId
impl TableId
Sourcepub fn new(namespace_id: NamespaceId, table_name: TableName) -> TableId
pub fn new(namespace_id: NamespaceId, table_name: TableName) -> TableId
Create a new TableId from namespace ID and table name
Sourcepub fn namespace_id(&self) -> &NamespaceId
pub fn namespace_id(&self) -> &NamespaceId
Get the namespace ID component
Sourcepub fn table_name(&self) -> &TableName
pub fn table_name(&self) -> &TableName
Get the table name component
Sourcepub fn from_strings(namespace_id: &str, table_name: &str) -> TableId
pub fn from_strings(namespace_id: &str, table_name: &str) -> TableId
Create from string components
Sourcepub fn try_from_strings(
namespace_id: &str,
table_name: &str,
) -> Result<TableId, String>
pub fn try_from_strings( namespace_id: &str, table_name: &str, ) -> Result<TableId, String>
Create from string components with validation errors instead of panics.
Sourcepub fn namespace_prefix(namespace_id: &NamespaceId) -> Vec<u8> ⓘ
pub fn namespace_prefix(namespace_id: &NamespaceId) -> Vec<u8> ⓘ
Create a prefix for scanning all tables in a namespace.
Sourcepub fn as_storage_key(&self) -> Vec<u8> ⓘ
pub fn as_storage_key(&self) -> Vec<u8> ⓘ
Format as bytes for storage using storekey tuple encoding
Sourcepub fn from_storage_key(key: &[u8]) -> Option<TableId>
pub fn from_storage_key(key: &[u8]) -> Option<TableId>
Parse from storage key bytes
Sourcepub fn into_parts(self) -> (NamespaceId, TableName)
pub fn into_parts(self) -> (NamespaceId, TableName)
Consume and return inner components